@@ -7,7 +7,7 @@ use std::sync::Arc;
 use regex::Regex;
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
-use yansi::{Paint, Style};
+use yansi::{Color, Paint, Style};
 
 use crate::config::Config;
 
@@ -136,7 +136,10 @@ fn parse_line(config: Arc<Config>, line: &str) -> Option<Info> {
         let unwrapped = serde_json::to_string(&msg).unwrap();
         //check if unwrapped is not an empty hashmap
         if unwrapped == "{}" {
-            println!("{}", line);
+            println!(
+                "{}",
+                apply_regexps(&config.regexp_colours, line.to_string())
+            );
             return None;
         }
 
@@ -162,14 +165,7 @@ fn parse_line(config: Arc<Config>, line: &str) -> Option<Info> {
         let mut themsg = msg.get("msg").unwrap().to_string();
 
         if !config.regexp_colours.is_empty() {
-            for (key, value) in config.regexp_colours.iter() {
-                let re = Regex::new(format!(r"(?P<r>{})", key.as_str()).as_str()).unwrap();
-                let style = Style::new(*value);
-                let _result = re
-                    .replace_all(&themsg, style.paint("$r").to_string())
-                    .to_string();
-                themsg = _result;
-            }
+            themsg = apply_regexps(&config.regexp_colours, themsg)
         }
         Some(Info {
             level,
@@ -182,6 +178,18 @@ fn parse_line(config: Arc<Config>, line: &str) -> Option<Info> {
     }
 }
 
+fn apply_regexps(regexps: &HashMap<String, Color>, msg: String) -> String {
+    let mut ret = msg;
+    for (key, value) in regexps.iter() {
+        let re = Regex::new(format!(r"(?P<r>{})", key.as_str()).as_str()).unwrap();
+        let style = Style::new(*value);
+        ret = re
+            .replace_all(&ret, style.paint("$r").to_string())
+            .to_string();
+    }
+    ret
+}
+
 pub fn read_from_stdin(config: Arc<Config>) {
     let stdin = io::stdin();
     for line in stdin.lock().lines() {
@@ -220,6 +228,9 @@ pub fn read_from_files(config: Arc<Config>) {
 #[cfg(test)]
 mod tests {
     use crate::config::Config;
+    use regex::Regex;
+    use std::collections::HashMap;
+    use yansi::Color;
 
     #[test]
     fn test_get_line() {
@@ -278,4 +289,22 @@ mod tests {
         assert!(msg.contains_key("others"));
         assert!(msg["others"].contains(" "));
     }
+    #[test]
+    fn test_apply_regexps() {
+        let line = String::from("red blue normal");
+        // define a regexp
+        let regexp = Regex::new(r"\b(b.ue)\b").unwrap();
+        let mut map = HashMap::new();
+        map.insert(String::from("red"), Color::Red);
+        map.insert(regexp.to_string(), Color::Blue);
+        let ret = super::apply_regexps(&map, line);
+        assert_eq!(
+            ret,
+            format!(
+                "{} {} normal",
+                Color::Red.paint("red"),
+                Color::Blue.paint("blue")
+            )
+        )
+    }
 }
